.babelrc
.codacy.yml
.editorconfig
.env.ci
.env.dusk.example
.env.example
.env.travis
.gitattributes
.github
.gitignore
.htaccess
.prettierrc
CODE_OF_CONDUCT.md
CONTRIBUTING.md
LICENSE
README.md
SECURITY.md
VERSION.txt
_ide_helper_custom.php
app
artisan
bootstrap
codecov.yml
composer.json
composer.lock
config
cypress.config.js
database
elastic
lang
modules_statuses.json
openapi
package-lock.json
package.json
phpstan.neon
phpunit.xml
postcss.config.cjs
preload.php
public
resources
routes
storage
tailwind.config.cjs
tests
vite.config.ts
vite.config.ts.react
webpack.mix.js
.env
vendor